/*
 * Copyright (C) The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package awesomeqrcodewrapper;

import anywheresoftware.b4a.AbsObjectWrapper;

import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Author;
import anywheresoftware.b4a.BA.Hide;
import anywheresoftware.b4a.BA.Pixel;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import anywheresoftware.b4a.BALayout;
import anywheresoftware.b4a.BA.DependsOn;
import anywheresoftware.b4a.keywords.Common.DesignerCustomView;
import anywheresoftware.b4a.objects.LabelWrapper;
import anywheresoftware.b4a.objects.PanelWrapper;
import anywheresoftware.b4a.objects.ViewWrapper;
import anywheresoftware.b4a.BA.ActivityObject;
import anywheresoftware.b4a.BA.Events;
import anywheresoftware.b4a.IOnActivityResult;
import anywheresoftware.b4a.BA.Permissions;

import android.content.Intent;
import android.os.Bundle;
import android.app.Activity;
import android.util.Log;
import android.view.View;
import android.widget.CompoundButton;
import android.widget.TextView;
import android.graphics.Color;

import java.util.ArrayList;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;

import com.github.sumimakito.awesomeqr.AwesomeQRCode;


//@ActivityObject
@ShortName("AwesomeQRCode_1")
//@Events(values={"lap_time(lapcounter As Int, laptime As String)"})
@Author("Github: SumiMakito(https://github.com/SumiMakito/AwesomeQRCode), Wrapped by: Johan Schoeman")
@Version(1.00f)
@DependsOn(values={"com.android.support:support-v4", "com.android.support:appcompat-v7","core-3.2.1"})
//@DependsOn(values={"core-3.2.1"})
@Permissions(values={"android.permission.WRITE_EXTERNAL_STORAGE", "android.permission.READ_EXTERNAL_STORAGE"})

public class awesomeqrcodeWrapper {

	
	private BA ba;
	private String eventName;
	private AwesomeQRCode.Renderer cv;
	
	
	public void Initialize(BA paramBA, String paramString) {
	    eventName = paramString.toLowerCase(BA.cul);
	    ba = paramBA;

	    String str = paramString.toLowerCase(BA.cul);
		cv = new AwesomeQRCode.Renderer();
	
	}	
	

    /**
     * If set to true, the dominant color of backgroundImage will be used as colorDark.
	 * Default = True
     */	
	public void autoColor(boolean autoColor) {
		cv.autoColor(autoColor);
	 }

	/**
     * Background image to embed in the QR code. Leave null to disable.
	 * Default = Null (or just don't set it at all)
     */	
	public void background(Bitmap backgroundImage) {
		cv.background(backgroundImage);
	}

	/**
     * If set to true, the whole image will be binarized with the given threshold, or default threshold if not specified.
	 * Default = False
     */	
	public void binarize(boolean binarize) {
		cv.binarize(binarize);
	}

	/**
     * Threshold used to binarize the whole image.
	 * Default = 128
     */	
	public void binarizeThreshold(int binarizeThreshold) {
		cv.binarizeThreshold(binarizeThreshold);
	}

	/**
     * Color of "true" blocks. Works only when both colorDark and colorLight are set.
	 * Default = Black
     */	
	public void colorDark(int colorDark) {
		cv.colorDark(colorDark);
	}

	/**
     * Color of empty space, or "false" blocks. Works only when both colorDark and colorLight are set.
	 * Default = White
     */	
	public void colorLight(int colorLight) {
		cv.colorLight(colorLight);
	}

	/**
     * Contents to encode.
	 * Default = Null (Required)
     */		
	public void contents(String contents) {
		cv.contents(contents);
	}

	/**
     * Value used to scale down the data dots' size.
	 * Default = 0.3f (set value from 0.0 to 1.0)
     */			
	public void dotScale(float dataDotScale) {
		cv.dotScale(dataDotScale);
	}

	/**
     * Logo image to embed at the center of generated QR code. Leave null to disable.
	 * Default = Null 
     */		
	public void logo(Bitmap logoImage) {
		cv.logo(logoImage);
	}

	/**
     * Radius of the logo's corners. Leave 0 to disable.
	 * Default = 8
     */		
	public void logoRadius(int logoCornerRadius) {
		cv.logoRadius(logoCornerRadius);
	}

	/**
     * White margin that appears around the logo image. Leave 0 to disable
	 * Default = 10
     */		
	public void logoMargin(int logoMargin) {
		cv.logoMargin(logoMargin);
	}

	/**
     * Value used to scale the logo image. Larger value may result in decode failure.
	 * Default = 0.2f (set value from 0.0 to 1.0)
     */			
	public void logoScale(float logoScale) {
		cv.logoScale(logoScale);
	}

	/**
     * Margin to add around the QR code.
	 * Default = 20 (Required)
     */			
	public void margin(int margin) {
		cv.margin(margin);
	}

	/**
     * If set to true, data dots will appear as solid dots instead of blocks.
	 * Default = False
     */			
	public void roundedDots(boolean roundedDataDots) {
		cv.roundedDots(roundedDataDots);
	}

	/**
     * Width as well as the height of the output QR code, includes margin.
	 * Default = 800
     */			
	public void size(int size) {
		cv.size(size);
	}

	/**
     * If set to true, a white border will appear around the background image.
	 * Default = True
     */		
	public void whiteMargin(boolean whiteMargin) {
		cv.whiteMargin(whiteMargin);
	}

	/**
     * Create the QR Code once all the parameters have been set
     */		
	public Bitmap render() {
		return cv.render();
	}

/*         public void renderAsync(final Callback callback) throws IllegalArgumentException {
            new Thread() {
                @Override
                public void run() {
                    super.run();
                    try {
                        Bitmap bitmap = create(
                                contents, size, margin, dataDotScale, colorDark, colorLight,
                                backgroundImage, whiteMargin, autoColor, binarize, binarizeThreshold,
                                roundedDataDots, logoImage, logoMargin, logoCornerRadius, logoScale
                        );
                        if (callback != null) callback.onRendered(Renderer.this, bitmap);
                    } catch (Exception e) {
                        if (callback != null) callback.onError(Renderer.this, e);
                    }
                }
            }.start();
        }
    }

    public interface Callback {
        void onRendered(Renderer renderer, Bitmap bitmap);

        void onError(Renderer renderer, Exception e);
    }	  */

 
	

	
}
